@@ -614,11 +614,17 @@ def predict_goals(pbp):
     #en_file = os.path.join('models', 'empty_net_model.pickle')
     #ue_file = os.path.join('models', 'uneven_model.pickle')
     
-    EV_MODEL = pickle.load(open(ev_file, 'rb'))
-    PP_MODEL = pickle.load(open(pp_file, 'rb'))
-    SH_MODEL = pickle.load(open(sh_file, 'rb'))
-    EN_MODEL = pickle.load(open(en_file, 'rb'))
-    UE_MODEL = pickle.load(open(ue_file, 'rb'))
+    #EV_MODEL = pickle.load(open(ev_file, 'rb'))
+    #PP_MODEL = pickle.load(open(pp_file, 'rb'))
+    #SH_MODEL = pickle.load(open(sh_file, 'rb'))
+    #EN_MODEL = pickle.load(open(en_file, 'rb'))
+    #UE_MODEL = pickle.load(open(ue_file, 'rb'))
+
+    EV_MODEL = pd.read_pickle(ev_file)
+    PP_MODEL = pd.read_pickle(pp_File)
+    SH_MODEL = pd.read_pickle(sh_File)
+    EN_MODEL = pd.read_pickle(en_File)
+    UE_MODEL = pd.read_pickle(ue_File)
     
     model_df = xG_prep(pbp)
 
